diff libpurple/protocols/jabber/jabber.h @ 30939:e0796db1df8a

Keep track of more than one relay request at a time (this is probably not likely to happen, but you never know...)
author Marcus Lundblad <ml@update.uu.se>
date Wed, 30 Sep 2009 21:31:04 +0000
parents 196e4c5b2043
children 0712ce23901e
line wrap: on
line diff
--- a/libpurple/protocols/jabber/jabber.h	Wed Sep 30 18:53:47 2009 +0000
+++ b/libpurple/protocols/jabber/jabber.h	Wed Sep 30 21:31:04 2009 +0000
@@ -276,7 +276,7 @@
 	/* stuff for Google's relay handling */
 	gchar *google_relay_token;
 	gchar *google_relay_host;
-	PurpleUtilFetchUrlData *google_relay_request; /* the HTTP request to get */
+	GList *google_relay_requests; /* the HTTP requests to get */
 												/* relay info */
 };